Enum rfc6381_codec::CodecError[][src]

pub enum CodecError {
    InvalidComponent(String),
    ExpectedHierarchySeparator(String),
    UnexpectedLength {
        expected: usize,
        got: String,
    },
}

Variants

InvalidComponent(String)
The given codec-string-component was not valid

ExpectedHierarchySeparator(String)
expected the ‘.’, but instead found the text included in the variant

UnexpectedLength
The length of the given string did not match the expected length

Show fields

Fields of UnexpectedLength

expected: usizegot: String